summaryrefslogtreecommitdiffstats
path: root/net/http/http_network_transaction.h
diff options
context:
space:
mode:
authorerikchen@google.com <erikchen@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-23 23:09:15 +0000
committererikchen@google.com <erikchen@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-23 23:09:15 +0000
commit9e9e842e287f9f949aa59bcf88321fa7f94fd524 (patch)
treeb84963a14d5c7a4a7908d268320d29bb40b726b2 /net/http/http_network_transaction.h
parent148971b8a6efa47182662a17c8e7b455043fb632 (diff)
downloadchromium_src-9e9e842e287f9f949aa59bcf88321fa7f94fd524.zip
chromium_src-9e9e842e287f9f949aa59bcf88321fa7f94fd524.tar.gz
chromium_src-9e9e842e287f9f949aa59bcf88321fa7f94fd524.tar.bz2
SPDY now always uses http_network_transaction instead of spdy_network_transaction.
It was previously possible to use spdy_network_transaction using the command line flags: --use-spdy=no-ssl --use-spdy=no-compress This does not affect instances of chrome that are not run with --use-spdy. Also changed spdy_network_transaction_unittest so that all tests are run with 3 different connection configurations: spdy over npn, spdy over ssl, and spdy without ssl. TEST=net_unittests BUG=49082 Review URL: http://codereview.chromium.org/3048003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@53548 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_network_transaction.h')
-rw-r--r--net/http/http_network_transaction.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/net/http/http_network_transaction.h b/net/http/http_network_transaction.h
index 7c32bd3..4d3cf4e 100644
--- a/net/http/http_network_transaction.h
+++ b/net/http/http_network_transaction.h
@@ -47,6 +47,12 @@ class HttpNetworkTransaction : public HttpTransaction {
// Controls whether or not we use the Alternate-Protocol header.
static void SetUseAlternateProtocols(bool value);
+ // Controls whether or not we use ssl when in spdy mode.
+ static void SetUseSSLOverSpdyWithoutNPN(bool value);
+
+ // Controls whether or not we use spdy without npn.
+ static void SetUseSpdyWithoutNPN(bool value);
+
// Sets the next protocol negotiation value used during the SSL handshake.
static void SetNextProtos(const std::string& next_protos);
@@ -274,11 +280,19 @@ class HttpNetworkTransaction : public HttpTransaction {
// responses.
bool logged_response_time_;
- bool using_ssl_; // True if handling a HTTPS request
+ // True if handling a HTTPS request, or using SPDY with SSL
+ bool using_ssl_;
// True if this network transaction is using SPDY instead of HTTP.
bool using_spdy_;
+ // True if this network transaction wants to use SPDY (not over npn)
+ bool want_spdy_without_npn_;
+
+ // True if this network transaction wants to use SSL with SPDY (not over npn)
+ bool want_ssl_over_spdy_without_npn_;
+
+
// The certificate error while using SPDY over SSL for insecure URLs.
int spdy_certificate_error_;